@@ -17,7 +17,7 @@ payload_marker_t* sv_payload_marker (const char* class_name) {
     return &sv_class_markers[class_name];
 }
 
-static SV* _next_create_wrapper (CV* cv, next_t type) {
+static SV* _next_create_wrapper (pTHX_ CV* cv, next_t type) {
     CvFLAGS(cv) |= CVf_NEXT_WRAPPER_CREATED;
     GV* gv = CvGV(cv);
     HV* stash = GvSTASH(gv);
@@ -44,7 +44,7 @@ static SV* _next_create_wrapper (CV* cv, next_t type) {
     return eval_pv(code.c_str(), 1);
 }
 
-SV* call_next (CV* cv, SV** args, I32 items, next_t type, I32 flags) {
+SV* call_next (pTHX_ CV* cv, SV** args, I32 items, next_t type, I32 flags) {
     SV* ret = NULL;
     if (CvFLAGS(cv) & CVf_NEXT_WRAPPER_CREATED) { // ensure module has a perl wrapper for cv
         dSP; ENTER; SAVETMPS;
@@ -68,7 +68,7 @@ SV* call_next (CV* cv, SV** args, I32 items, next_t type, I32 flags) {
         FREETMPS; LEAVE;
     }
     else {
-        SV* wrapper = _next_create_wrapper(cv, type);
+        SV* wrapper = _next_create_wrapper(aTHX_ cv, type);
         dSP; ENTER; SAVETMPS;
         PUSHMARK(SP);
         for (I32 i = 0; i < items; ++i) XPUSHs(*args++);
@@ -84,12 +84,12 @@ SV* call_next (CV* cv, SV** args, I32 items, next_t type, I32 flags) {
     return ret;
 }
 
-static inline HV* _get_stash (HV* stash)         { return stash; }
-static inline HV* _get_stash (SV* CLASS)         { return gv_stashsv(CLASS, GV_ADD); }
-static inline HV* _get_stash (const char* CLASS) { return gv_stashpvn(CLASS, strlen(CLASS), GV_ADD); }
+static inline HV* _get_stash (pTHX_ HV* stash)         { return stash; }
+static inline HV* _get_stash (pTHX_ SV* CLASS)         { return gv_stashsv(CLASS, GV_ADD); }
+static inline HV* _get_stash (pTHX_ const char* CLASS) { return gv_stashpvn(CLASS, strlen(CLASS), GV_ADD); }
 
 template <typename C>
-static inline SV* _typemap_out_oext_ (SV* obase, void* var, C CLASS, payload_marker_t* marker) {
+static inline SV* _typemap_out_oext_ (pTHX_ SV* obase, void* var, C CLASS, payload_marker_t* marker) {
     if (!var) return &PL_sv_undef;
     SV* objrv;
     if (obase) {
@@ -99,27 +99,27 @@ static inline SV* _typemap_out_oext_ (SV* obase, void* var, C CLASS, payload_mar
         }
         else {
             objrv = newRV_noinc(obase);
-            sv_bless(objrv, _get_stash(CLASS));
+            sv_bless(objrv, _get_stash(aTHX_ CLASS));
         }
     } else {
         obase = newSV(0);
         objrv = newRV_noinc(obase);
-        sv_bless(objrv, _get_stash(CLASS));
+        sv_bless(objrv, _get_stash(aTHX_ CLASS));
     }
-    sv_payload_attach(obase, var, marker);
+    sv_payload_attach(aTHX_ obase, var, marker);
     return objrv;
 }
 
-SV* _typemap_out_oext (SV* obase, void* var, HV* CLASS, payload_marker_t* marker) {
-    return _typemap_out_oext_(obase, var, CLASS, marker);
+SV* _typemap_out_oext (pTHX_ SV* obase, void* var, HV* CLASS, payload_marker_t* marker) {
+    return _typemap_out_oext_(aTHX_ obase, var, CLASS, marker);
 }
 
-SV* _typemap_out_oext (SV* obase, void* var, SV* CLASS, payload_marker_t* marker) {
-    return _typemap_out_oext_(obase, var, CLASS, marker);
+SV* _typemap_out_oext (pTHX_ SV* obase, void* var, SV* CLASS, payload_marker_t* marker) {
+    return _typemap_out_oext_(aTHX_ obase, var, CLASS, marker);
 }
 
-SV* _typemap_out_oext (SV* obase, void* var, const char* CLASS, payload_marker_t* marker) {
-    return _typemap_out_oext_(obase, var, CLASS, marker);
+SV* _typemap_out_oext (pTHX_ SV* obase, void* var, const char* CLASS, payload_marker_t* marker) {
+    return _typemap_out_oext_(aTHX_ obase, var, CLASS, marker);
 }
 
 };
